@@ -3,7 +3,7 @@ package HTTP::Daemon::App;
 use strict;
 use warnings;
 
-use version;our $VERSION = qv(0.0.1);
+use version;our $VERSION = qv(0.0.2);
 
 use HTTP::Daemon;
 use HTTP::Daemon::SSL;
@@ -25,7 +25,7 @@ sub run {
     my($daemons_hashref, $conf) = @_;  
     
     $conf->{'pid_dir'} = File::Spec->catdir(qw(/ var run)) if !$conf->{'pid_dir'};
-    $conf->{'pid_ext'} = '.pid' if $conf->{'pid_ext'};
+    $conf->{'pid_ext'} = '.pid' if !$conf->{'pid_ext'};
     $conf->{'self'}    = "perl $0" if !$conf->{'self'};
     
     my $additional = '';
@@ -37,6 +37,7 @@ sub run {
         $additional .= "|$opt";
     }
     
+    $ARGV[0] = '--help' if !defined $ARGV[0]; # no uninit warnings and logical visual clue to coders of what will happen if its not specified...
     if($ARGV[0] eq '--restart') {
         system qq($conf->{'self'} --stop);
         sleep 1;
@@ -81,7 +82,13 @@ sub run {
     elsif($ARGV[0] eq '--stop') {
     	for my $daemon (sort keys %{ $daemons_hashref }) {
     	    my $pidfile = File::Spec->catfile($conf->{'pid_dir'}, "$daemon$conf->{'pid_ext'}");
-    	    Unix::PID->new()->kill_pid_file($pidfile);
+    	    my $pid = Unix::PID->new()->kill_pid_file($pidfile);
+    	    if($pid == 1) {
+    	        print "$daemon is not running\n";
+    	    }
+    	    else {
+    	        print "$daemon ($pid) was stopped\n";
+    	    }
     	}
     }
     elsif(exists $conf->{'opts'}{$ARGV[0]}) {
